==> paraview-5.12.1-8-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/Datamine-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonExecutionModel")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonTransforms;VTK::FiltersCore")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_library_name" "vtkDatamineReaders")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineBlockReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineDrillHoleReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineDummyReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMinePerimeterReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMinePointReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineWireFrameReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDatamineReadersModule.h")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/Datamine/vtk/hierarchy/Datamine/vtkDatamineReaders-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/Datamine-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonExecutionModel")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonTransforms;VTK::FiltersCore")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_library_name" "vtkDatamineReaders")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineBlockReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineDrillHoleReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineDummyReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMinePerimeterReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMinePointReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDataMineWireFrameReader.h")
set_property(TARGET "Datamine::DatamineReaders" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/Datamine/vtk/hierarchy/Datamine/vtkDatamineReaders-hierarchy.txt")
unset(_vtk_module_import_prefix)
